function distance = eigenValuesBasedAnalysis(data,nEigen,numberOfDimentions)
%
% This function calculates absolute distance from points to origin, based
% on the idea that distance along one principal component is proportional
% to the amount of variance explained by that component, wich can be
% obtained by analysing eigenvalues.
%  
% 
% Calculates diferent kinds of normalization and stores
% the result in a stucture.
% 
% distance = eigenValuesBasedAnalysis(data,nEigen,numberOfDimentions)
% 
% - Input arguments
%
%           data: matrix n x m with n observations of m dimensions each
%           nEigen: Eigen Values of data
%           numberOfDimentions : number of eigen values to analyse
%
%     
% - Output arguments
%     
%           distance: vector of size 1 x n with distances to origin
%
%
% CLASSE Project
% Created by Paulo Barbeiro - FCTUC
% barbeiro@student.dei.uc.pt
% Updated April 20, 2007
%
% Copyright (C) 2007 Paulo Barbeiro  FCTUC Coimbra, Portugal
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.

sampleMatrix=data(:,1:numberOfDimentions);
sampleEigen=nEigen(1:numberOfDimentions);
sampleEigen=sampleEigen/sum(sampleEigen);
for i=1:numberOfDimentions
    newPoints(:,i)=sampleMatrix(:,i)*sampleEigen(i);
end

distance=squareform(pdist(newPoints));
distance=distance(1,:);
